==> PNet-1.1.2-sources.jar: de/ecconia/java/pnet/stream/StreamReader.java <==
package de.ecconia.java.pnet.stream;

import java.io.IOException;
import java.io.InputStream;
import java.net.SocketException;

import de.ecconia.java.pnet.exceptions.NetworkException;
import de.ecconia.java.pnet.exceptions.NetworkException.ClosingNetworkException;
import de.ecconia.java.pnet.exceptions.NetworkException.DisconnectedException;
import de.ecconia.java.pnet.exceptions.NetworkException.EndOfStreamException;
import de.ecconia.java.pnet.exceptions.NetworkException.ConnectionResetException;
import de.ecconia.java.pnet.exceptions.NetworkException.UnknownNetworkException;

public class StreamReader implements Reader
{
	private final InputStream is;
	
	public StreamReader(InputStream is)
	{
		this.is = is;
	}
	
	public byte readByte() throws NetworkException
	{
		try
		{
			int i = is.read();
			
			if(i < 0)
			{
				throw new EndOfStreamException();
			}
			
			return (byte) i;
		}
		catch(IOException e)
		{
			//TODO: Find (more) cases!
			if(e instanceof SocketException)
			{
				if("Connection reset".equals(e.getMessage()))
				{
					throw new DisconnectedException();
				}
			}
			
			throw new UnknownNetworkException(e);
		}
	}
	
	public byte[] readBytes(int amount) throws NetworkException
	{
		try
		{
			byte[] bytes = new byte[amount];
			
			int pointer = 0;
			int remaining = amount;
			
			while(remaining > 0)
			{
				int amountRead = is.read(bytes, pointer, remaining);
				if(amountRead < 0)
				{
					throw new EndOfStreamException();
				}
				
				remaining -= amountRead;
				pointer += amountRead;
			}
			
			return bytes;
		}
		catch(IOException e)
		{
			if(e instanceof SocketException)
			{
				if("Socket closed".equals(e.getMessage()))
				{
					throw new ClosingNetworkException();
				}
				else if("socket closed".equals(e.getMessage()))
				{
					throw new ClosingNetworkException();
				}
				else if("Connection reset".equals(e.getMessage()))
				{
					throw new ConnectionResetException();
				}
			}
			
			//TODO: Find cases!
			throw new UnknownNetworkException(e);
		}
	}
}

==> PNet-1.1.3-sources.jar: de/ecconia/java/pnet/stream/StreamReader.java <==
package de.ecconia.java.pnet.stream;

import java.io.IOException;
import java.io.InputStream;
import java.net.SocketException;

import de.ecconia.java.pnet.exceptions.NetworkException;
import de.ecconia.java.pnet.exceptions.NetworkException.ClosingNetworkException;
import de.ecconia.java.pnet.exceptions.NetworkException.ConnectionResetException;
import de.ecconia.java.pnet.exceptions.NetworkException.ConnectionTimeoutException;
import de.ecconia.java.pnet.exceptions.NetworkException.DisconnectedException;
import de.ecconia.java.pnet.exceptions.NetworkException.EndOfStreamException;
import de.ecconia.java.pnet.exceptions.NetworkException.UnknownNetworkException;

public class StreamReader implements Reader
{
	private final InputStream is;
	
	public StreamReader(InputStream is)
	{
		this.is = is;
	}
	
	public byte readByte() throws NetworkException
	{
		try
		{
			int i = is.read();
			
			if(i < 0)
			{
				throw new EndOfStreamException();
			}
			
			return (byte) i;
		}
		catch(IOException e)
		{
			//TODO: Find (more) cases!
			if(e instanceof SocketException)
			{
				if("Connection reset".equals(e.getMessage()))
				{
					throw new DisconnectedException();
				}
			}
			
			throw new UnknownNetworkException(e);
		}
	}
	
	public byte[] readBytes(int amount) throws NetworkException
	{
		try
		{
			byte[] bytes = new byte[amount];
			
			int pointer = 0;
			int remaining = amount;
			
			while(remaining > 0)
			{
				int amountRead = is.read(bytes, pointer, remaining);
				if(amountRead < 0)
				{
					throw new EndOfStreamException();
				}
				
				remaining -= amountRead;
				pointer += amountRead;
			}
			
			return bytes;
		}
		catch(IOException e)
		{
			if(e instanceof SocketException)
			{
				if("Socket closed".equals(e.getMessage()))
				{
					throw new ClosingNetworkException();
				}
				else if("socket closed".equals(e.getMessage())) //Whichever weird JVM class sets this reason.
				{
					throw new ClosingNetworkException();
				}
				else if("Connection reset".equals(e.getMessage()))
				{
					throw new ConnectionResetException();
				}
				else if("Connection timed out (Read failed)".equals(e.getMessage()))
				{
					throw new ConnectionTimeoutException();
				}
			}
			
			//TODO: Find cases!
			throw new UnknownNetworkException(e);
		}
	}
}
